@@ -3,6 +3,9 @@
 #' @description
 #' For the definition of \dQuote{atomic}, see \code{\link[base]{is.atomic}}.
 #'
+#' Note that `NULL` is recognized as a valid atomic value, as in R versions up to version 4.3.x.
+#' For details, see \url{https://stat.ethz.ch/pipermail/r-devel/2023-September/082892.html}.
+#'
 #' @templateVar fn Atomic
 #' @template x
 #' @inheritParams checkVector
@@ -25,7 +28,7 @@ check_atomic = checkAtomic
 #' @include makeAssertion.R
 #' @template assert
 #' @rdname checkAtomic
-assertAtomic = makeAssertionFunction(checkAtomic, c.fun = "c_check_atomic")
+assertAtomic = makeAssertionFunction(checkAtomic, c.fun = "c_check_atomic", use.namespace = FALSE)
 
 #' @export
 #' @rdname checkAtomic
@@ -44,4 +47,4 @@ test_atomic = testAtomic
 #' @include makeExpectation.R
 #' @template expect
 #' @rdname checkAtomic
-expect_atomic = makeExpectationFunction(checkAtomic, c.fun = "c_check_atomic")
+expect_atomic = makeExpectationFunction(checkAtomic, c.fun = "c_check_atomic", use.namespace = FALSE)
