@@ -5,6 +5,7 @@
 #' @template na-handling
 #' @inheritParams checkVector
 #' @template null.ok
+#' @template typed.missing
 #' @template checker
 #' @family basetypes
 #' @useDynLib checkmate c_check_logical
@@ -12,8 +13,8 @@
 #' @examples
 #' testLogical(TRUE)
 #' testLogical(TRUE, min.len = 1)
-checkLogical = function(x, any.missing = TRUE, all.missing = TRUE, len = NULL, min.len = NULL, max.len = NULL, unique = FALSE, names = NULL, null.ok = FALSE) {
-  .Call(c_check_logical, x, any.missing, all.missing, len, min.len, max.len, unique, names, null.ok)
+checkLogical = function(x, any.missing = TRUE, all.missing = TRUE, len = NULL, min.len = NULL, max.len = NULL, unique = FALSE, names = NULL, typed.missing = FALSE, null.ok = FALSE) {
+  .Call(c_check_logical, x, any.missing, all.missing, len, min.len, max.len, unique, names, typed.missing, null.ok)
 }
 
 #' @export
