@@ -5,13 +5,15 @@ const char * guess_type(SEXP x) {
     SEXP attr = getAttrib(x, R_ClassSymbol);
     if (!isNull(attr)) {
         const R_len_t n = length(attr);
-        if (n == 1)
+        if (n == 1) {
             return CHAR(STRING_ELT(attr, 0));
+        }
 
         /* Constuct name using [class1]/[class2]/... */
         static char buf[512];
         const char * tmp = CHAR(STRING_ELT(attr, 0));
-        strncpy(buf, tmp, 512);
+        strncpy(buf, tmp, 511);
+        buf[511] = '\0';
         R_len_t written = strlen(tmp);
         for (R_len_t i = 1; i < n; i++) {
             tmp = CHAR(STRING_ELT(attr, i));
