@@ -39,19 +39,18 @@ R_len_t attribute_hidden get_ncols(SEXP x) {
     return (length(dim) >= 2) ? INTEGER_RO(dim)[1] : 1;
 }
 
-
-double attribute_hidden asNumber(SEXP x, const char *vname) {
+double attribute_hidden as_number(SEXP x, const char *vname) {
     if (!isNumeric(x))
         error("Argument '%s' must be a number, but is %s", vname, guess_type(x));
     if (xlength(x) != 1)
-        error("Argument '%s' must have length 1, but has length %i", vname, xlength(x));
+        error("Argument '%s' must have length 1, but has length %g", vname, (double)xlength(x));
     double xd = asReal(x);
     if (ISNAN(xd))
         error("Argument '%s' may not be missing", vname);
     return xd;
 }
 
-const char attribute_hidden * asString(SEXP x, const char *vname) {
+const char attribute_hidden * as_string(SEXP x, const char *vname) {
     if (!isString(x) || xlength(x) != 1)
         error("Argument '%s' must be a string, but is %s", vname, guess_type(x));
     if (find_missing_string(x) > 0)
@@ -59,9 +58,9 @@ const char attribute_hidden * asString(SEXP x, const char *vname) {
     return CHAR(STRING_ELT(x, 0));
 }
 
-R_len_t attribute_hidden asCount(SEXP x, const char *vname) {
+R_len_t attribute_hidden as_count(SEXP x, const char *vname) {
     if (length(x) != 1)
-        error("Argument '%x' must have length 1", vname);
+        error("Argument '%s' must have length 1", vname);
     if (!isIntegerish(x, INTEGERISH_DEFAULT_TOL, FALSE))
         error("Argument '%s' must be numeric and close to an integer", vname);
     int xi = asInteger(x);
@@ -72,9 +71,9 @@ R_len_t attribute_hidden asCount(SEXP x, const char *vname) {
     return xi;
 }
 
-R_xlen_t attribute_hidden asLength(SEXP x, const char *vname) {
+R_xlen_t attribute_hidden as_length(SEXP x, const char *vname) {
     if (length(x) != 1)
-        error("Argument '%x' must have length 1", vname);
+        error("Argument '%s' must have length 1", vname);
     switch(TYPEOF(x)) {
         case INTSXP:;
             int xi = INTEGER_RO(x)[0];
@@ -96,7 +95,7 @@ R_xlen_t attribute_hidden asLength(SEXP x, const char *vname) {
     error("Argument '%s' must be a length, but is %s", vname, guess_type(x));
 }
 
-Rboolean attribute_hidden asFlag(SEXP x, const char *vname) {
+Rboolean attribute_hidden as_flag(SEXP x, const char *vname) {
     if (!isLogical(x) || xlength(x) != 1)
         error("Argument '%s' must be a flag, but is %s", vname, guess_type(x));
     Rboolean xb = LOGICAL_RO(x)[0];
@@ -144,5 +143,5 @@ Rboolean is_class_array(SEXP x) { return isArray(x); }
 Rboolean is_class_frame(SEXP x) { return isFrame(x); }
 Rboolean is_class_environment(SEXP x) { return isEnvironment(x); }
 Rboolean is_class_null(SEXP x) { return isNull(x); }
-Rboolean is_class_posixct(SEXP x) { return isReal(x) && inherits(x, "POSIXct"); }
+Rboolean is_class_posixct(SEXP x) { return isNumeric(x) && inherits(x, "POSIXct"); }
 Rboolean is_class_raw(SEXP x) { return TYPEOF(x) == RAWSXP; }
